@@ -84,6 +84,7 @@ class APIClientBase:
         query_args: dict = None,
         body: dict = None,
         success_codes: list = None,
+        on_response_callback=None,
         **kwargs,
     ):
         url = self._make_url(relative_url, *args, query_args=query_args, **kwargs)
@@ -93,16 +94,20 @@ class APIClientBase:
             success_codes = APIClientBase.SUCCESS_CODES[method]
 
         if self._use_asyncio and is_event_loop_available():
-            return self._async_request(method, url, body, success_codes, error_subject)
+            return self._async_request(method, url, body, success_codes, error_subject, on_response_callback)
         else:
-            return self._sync_request(method, url, body, success_codes, error_subject)
+            return self._sync_request(method, url, body, success_codes, error_subject, on_response_callback)
 
-    async def _async_request(self, method: str, url: str, body: dict, success_codes: list, error_subject: str):
+    async def _async_request(
+        self, method: str, url: str, body: dict, success_codes: list, error_subject: str, on_response_callback
+    ):
         try:
             logger.debug(f"Calling {method} {url} with aiohttp lib")
             # loop = asyncio.get_event_loop()
             # return loop.run_until_complete(self._async_request(method, url, body, success_codes, error_subject))
-            return await self._unsafe_async_request(method, url, body, success_codes, error_subject)
+            return await self._unsafe_async_request(
+                method, url, body, success_codes, error_subject, on_response_callback
+            )
 
         except APIException as e:
             raise
@@ -132,7 +137,9 @@ class APIClientBase:
             error = self._append_url_if_not_local_service(str(e) or type(e).__name__)
             raise APIException(url=url, message=f"{error_subject} has failed ({error})", request_body=body,) from e
 
-    async def _unsafe_async_request(self, method: str, url: str, body: dict, success_codes: list, error_subject: str):
+    async def _unsafe_async_request(
+        self, method: str, url: str, body: dict, success_codes: list, error_subject: str, on_response_callback
+    ):
         headers = None
         if self.headers is not None and len(self.headers) > 0:
             headers = self.headers
@@ -158,7 +165,8 @@ class APIClientBase:
                 if response.status in success_codes:
                     logger.debug(f"Received {response.status} from {method} {url}")
                     if is_json or self._force_json:
-                        return await response.json()
+                        json_response = await response.json()
+                        return on_response_callback(json_response) if on_response_callback else json_response
                     else:
                         return await response.read()
 
@@ -172,10 +180,12 @@ class APIClientBase:
                     response=response,
                 )
 
-    def _sync_request(self, method: str, url: str, body: dict, success_codes: list, error_subject: str):
+    def _sync_request(
+        self, method: str, url: str, body: dict, success_codes: list, error_subject: str, on_response_callback
+    ):
         try:
             logger.debug(f"Calling {method} {url} with requests lib")
-            return self._unsafe_sync_request(method, url, body, success_codes, error_subject)
+            return self._unsafe_sync_request(method, url, body, success_codes, error_subject, on_response_callback)
 
         except APIException as e:
             raise
@@ -205,7 +215,9 @@ class APIClientBase:
             error = self._append_url_if_not_local_service(str(e) or type(e).__name__)
             raise APIException(url=url, message=f"{error_subject} has failed ({error})", request_body=body) from e
 
-    def _unsafe_sync_request(self, method: str, url: str, body: dict, success_codes: list, error_subject: str):
+    def _unsafe_sync_request(
+        self, method: str, url: str, body: dict, success_codes: list, error_subject: str, on_response_callback
+    ):
         method_func = self._get_method_func(method)
         method_args = {"verify": self._verify_ssl_cert}
         if self.headers is not None and len(self.headers) > 0:
@@ -219,7 +231,8 @@ class APIClientBase:
         if response.status_code in success_codes:
             logger.debug(f"Received {response.status_code} from {method} {url}")
             if is_json or self._force_json:
-                return response.json()
+                json_response = response.json()
+                return on_response_callback(json_response) if on_response_callback else json_response
             else:
                 return response.content
 
@@ -311,7 +324,7 @@ class APIClientBase:
 
 def get_http_code_error_message(status_code):
     if status_code == 404:
-        return "object nout found"
+        return "object not found"
     if status_code == 401:
         return "unauthorized"
     if status_code == 403:
