@@ -8,9 +8,7 @@ class Authentication(APIClientBase):
     def __init__(self, url_base=None, **kwargs):
         super().__init__(url_base or os.environ.get("AUTHORIZATION_SERVICE", ""), **kwargs)
 
-    def login(self, username: str, password: str):
-        body = {"username": username, "password": password}
-        response = self.post_request("/login", body=body)
+    def on_login_response(self, response):
         if "jwt" in response:
             token = response["jwt"]
             parsed_base_url = urllib.parse.urlparse(self.url_base)
@@ -18,6 +16,10 @@ class Authentication(APIClientBase):
             keyring.set_token(token)
         return response
 
+    def login(self, username: str, password: str):
+        body = {"username": username, "password": password}
+        return self.post_request("/login", body=body, on_response_callback=self.on_login_response)
+
     def get_public_key(self, username: str):
         return self.get_request("/public-key", query_args={"username": username})
 
