@@ -1,5 +1,5 @@
 import os
-from typing import Any, Optional
+from typing import Any, Optional, List, Dict
 from .api_client import APIClientBase
 
 
@@ -17,8 +17,8 @@ class Central(APIClientBase):
         }
         return self.post_request("/licensing/activate", body=body)
 
-    def sync_product_licensing_information(self) -> Any:
-        return self.post_request("/licensing/sync")
+    def sync(self) -> Any:
+        return self.post_request("/sync")
 
     def is_monitoring_purchased(self) -> Any:
         return self.get_request("/monitoring/is-purchased")
@@ -26,11 +26,20 @@ class Central(APIClientBase):
     def is_monitoring_enabled(self) -> Any:
         return self.get_request("/monitoring/is-enabled")
 
-    def get_monitoring_endpoints(self) -> Any:
-        return self.get_request("/monitoring/endpoints")
-
     def enable_monitoring(self) -> Any:
         return self.post_request("/monitoring/enable")
 
     def disable_monitoring(self) -> Any:
         return self.post_request("/monitoring/disable")
+
+    def configure_monitoring(self, exporters: List[Any]) -> Any:
+        body: Dict = {
+            "exporters": exporters,
+        }
+        return self.post_request("/monitoring/configure", body=body)
+
+    def get_external_services(self) -> Any:
+        return self.get_request("/external-services")
+
+    def get_certificates(self) -> Any:
+        return self.get_request("/certificates")
\ No newline at end of file
